# Emeritus Domain-Specific Language 
<p align="center">
  <img src="https://github.com/goemeritus/edsl-public/blob/main/static/logo.png?raw=true" alt="edsl.png" width="100"/>
</p>

The Emeritus Domain-Specific Language (EDSL) package lets you conduct social science and market research with AI. Use it to design surveys and experiments, simulate responses with LLMs, and analyze results. 


## 🔗 Links
- PyPI: https://pypi.org/project/edsl/
- Documentation: https://www.goemeritus.com/getting-started/
- Discord: https://discord.com/invite/mxAYkjfy9m

## 💡 Contributing, Feature Asks, and Bugs
Interested in contributing? Want us to add a new feature? Found a nasty bug that you would like us to squash? Please send us an email at info@goemeritus.com or message us at our discord server.


## 💻 Getting started
Our package is compatible with Python 3.9 - 3.11.
```
pip install edsl
```

See https://www.goemeritus.com/getting-started/
 for examples and tutorials.

## 🔧 Dependencies
The main third-party package requirement is  `openai`.

